@@ -1,15 +1,10 @@
 from redis import Redis as RedisClass
-import inspect
-import urlparse
-from werkzeug.utils import import_string
 
 __all__ = ('Redis',)
 
 
 class Redis(object):
 
-    converters = {'port': int}
-
     def __init__(self, app=None, config_prefix=None):
         """
         Constructor for non-factory Flask applications
@@ -20,7 +15,6 @@ class Redis(object):
         if app is not None:
             self.init_app(app)
 
-
     def init_app(self, app):
         """
         Apply the Flask app configuration to a Redis object
@@ -32,15 +26,10 @@ class Redis(object):
             suffix
         )
 
-        self.app.config.setdefault(self.key('URL'), 'redis://localhost')
-        self.app.config.setdefault(self.key('DATABASE'), 0)
+        self.app.config.setdefault(self.key('URL'), 'redis://localhost:6379')
 
         db = self.app.config.get(self.key('DATABASE'))
 
-
-        if not str(db).isdigit() or not isinstance(db, int):
-            raise ValueError('A valid DB must be supplied')
-
         self.connection = connection = RedisClass.from_url(
             self.app.config.get(self.key('URL')),
             db=db,
